powered by
Fill scale constructor for The Globe and Mail's colors
scale_fill_tgam(palette = "main", discrete = TRUE, reverse = FALSE, ...)
Character name of palette in tgam_palettes. Currently, one of 'main' or 'alternate'.
Boolean indicating whether color aesthetic is discrete or not
Boolean indicating whether the palette should be reversed
Additional arguments passed to discrete_scale() or scale_fill_gradientn(), used respectively when discrete is TRUE or FALSE
A ggplot2 colour scale object, to be passed to a ggplot2 object
# NOT RUN { library(ggplot2) ggplot(diamonds, aes(carat, fill = cut)) + geom_density(position = 'fill') + scale_fill_tgam() # }
Run the code above in your browser using DataLab